(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8632,        262]*)
(*NotebookOutlinePosition[      9286,        285]*)
(*  CellTagsIndexPosition[      9242,        281]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Golden Mean Sequence", "Title"],

Cell["\<\
Before you run any of this notebook, evaluate the cells in the \"Code\" \
section of the notebook algorithms-chapter.nb first.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Code", "Section"],

Cell[CellGroupData[{

Cell["Data Loading", "Subsection"],

Cell["\<\
Automatically attempt to load data. If the file maskit-mathematica-2000.txt \
is not in a subdirectory of your home directory, simply change the next \
expression to the line:
<<\"directory\\\\maskit-mathematica-2000.txt\"
where 'directory' is the directory where the file maskit-mathematica-2000.txt \
is kept, and all symbols \\ are replaced by \\\\.\
\>", "Text"],

Cell[BoxData[{
    \(\(filenames = 
        FileNames["\<maskit-mathematica-2000.txt\>", $HomeDirectory, 
          Infinity];\)\), "\[IndentingNewLine]", 
    \(\(If[
        Length[filenames] \[GreaterEqual] 
          1, \[IndentingNewLine]\(Get[
            filenames\[LeftDoubleBracket]1\[RightDoubleBracket]];\)];\)\)}], \
"Input"],

Cell[BoxData[
    \(\(LookupCusp[0] := 2\ I;\)\)], "Input"],

Cell[BoxData[
    \(\(LookupCusp[1] := 2\ I\  + \ 2;\)\)], "Input"],

Cell[BoxData[
    \(\(\(\((\(LookupCusp[#1\[LeftDoubleBracket]2\[RightDoubleBracket]] = #1\
\[LeftDoubleBracket]1\[RightDoubleBracket];\))\) &\) /@ 
        maskitbdy\[LeftDoubleBracket]2\[RightDoubleBracket];\)\)], "Input"],

Cell["\<\
Automatically attempt to load data. If the file tda2000.txt is not in a \
subdirectory of your home directory, simply change the next expression to the \
line:
<<\"directory\\\\tda2000.txt\"
where 'directory' is the directory where the file tda2000.txt is kept, and \
all symbols \\ are replaced by \\\\.\
\>", "Text"],

Cell[BoxData[{
    \(\(filenames = 
        FileNames["\<tda2000.txt\>", $HomeDirectory, 
          Infinity];\)\), "\[IndentingNewLine]", 
    \(\(If[
        Length[filenames] \[GreaterEqual] 
          1, \[IndentingNewLine]\(Get[
            filenames\[LeftDoubleBracket]1\[RightDoubleBracket]];\)];\)\)}], \
"Input"],

Cell[BoxData[
    \(\(TraceDeriv[1] := TraceDeriv[0];\)\)], "Input"],

Cell[BoxData[
    \(\(\(\((\(TraceDeriv[#1\[LeftDoubleBracket]1\[RightDoubleBracket]] = #1\
\[LeftDoubleBracket]2\[RightDoubleBracket];\))\) &\) /@ 
        tracederivatives;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Golden mean sequence", "Subsection"],

Cell[BoxData[
    \(\(cf = Join[{0}, Table[1, {1000}]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(approxgoldenmean = 
      FromContinuedFraction /@ Table[Take[cf, n], {n, 2, 20}]\)], "Input"],

Cell[BoxData[
    \({1, 1\/2, 2\/3, 3\/5, 5\/8, 8\/13, 13\/21, 21\/34, 34\/55, 55\/89, 
      89\/144, 144\/233, 233\/377, 377\/610, 610\/987, 987\/1597, 1597\/2584, 
      2584\/4181, 4181\/6765}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(approxgoldenmean = 
      Select[approxgoldenmean, 
        Denominator[#1] \[LessEqual] 2000 &]\)], "Input"],

Cell[BoxData[
    \({1, 1\/2, 2\/3, 3\/5, 5\/8, 8\/13, 13\/21, 21\/34, 34\/55, 55\/89, 
      89\/144, 144\/233, 233\/377, 377\/610, 610\/987, 987\/1597}\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Results", "Section"],

Cell["\<\
This table shows that for every other partial approximant to the golden mean, \
the cusp direction, or equivalently the initial direction of the pleating \
ray, is vertical.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      Transpose[{approxgoldenmean, \(Im[Log[1/TraceDeriv[#1]]] &\) /@ 
            approxgoldenmean, Table[Pi/2. , {Length[approxgoldenmean]}]}], 
      TableHeadings \[Rule] {{}, {"\<p/q\>", \
"\<Im[Log[1/TraceDeriv[p/q]]]\>", "\<\[Pi]/2\>"}}]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"p/q\"\>", "\<\"Im[Log[TraceDeriv[p/q]]]\"\>", "\<\
\"\[Pi]/2\"\>"},
          {"\<\"\"\>", "1", "1.5707963267948966192313216916`16.3012", 
            "1.5707963267948966`"},
          {"\<\"\"\>", \(1\/2\), "1.5707963235899587`", 
            "1.5707963267948966`"},
          {"\<\"\"\>", \(2\/3\), "1.6956756028608977`", 
            "1.5707963267948966`"},
          {"\<\"\"\>", \(3\/5\), "1.5707963254261372`", 
            "1.5707963267948966`"},
          {"\<\"\"\>", \(5\/8\), "1.738457922894379`", 
            "1.5707963267948966`"},
          {"\<\"\"\>", \(8\/13\), "1.5707963277883825`", 
            "1.5707963267948966`"},
          {"\<\"\"\>", \(13\/21\), "1.7517648368748497`", 
            "1.5707963267948966`"},
          {"\<\"\"\>", \(21\/34\), "1.5707963201403872`", 
            "1.5707963267948966`"},
          {"\<\"\"\>", \(34\/55\), "1.755505180744496`", 
            "1.5707963267948966`"},
          {"\<\"\"\>", \(55\/89\), "1.5707963268348784`", 
            "1.5707963267948966`"},
          {"\<\"\"\>", \(89\/144\), "1.7564882580024195`", 
            "1.5707963267948966`"},
          {"\<\"\"\>", \(144\/233\), "1.5707963263887317`", 
            "1.5707963267948966`"},
          {"\<\"\"\>", \(233\/377\), "1.7567356537683698`", 
            "1.5707963267948966`"},
          {"\<\"\"\>", \(377\/610\), "1.5707963262079845`", 
            "1.5707963267948966`"},
          {"\<\"\"\>", \(610\/987\), "1.7567960856694482`", 
            "1.5707963267948966`"},
          {"\<\"\"\>", \(987\/1597\), "1.5707963291292681`", 
            "1.5707963267948966`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableHeadings -> {{}, {"p/q", "Im[Log[TraceDeriv[p/q]]]",
         "\[Pi]/2"}}]&)]], "Output"]
}, Open  ]],

Cell["\<\
This sequence of pictures shows the fact above graphically. In the first \
picture, you should be looking at the 1/2-cusp and pleating ray, and the 3/5.\
\
\>", "Text"],

Cell[BoxData[
    \(\(bdy40 = 
        ComputeAndPlot[InitialBoundarySpecifier[40], ShowLabels \[Rule] 8, 
          ShowPleating \[Rule] 15];\)\)], "Input"],

Cell["In the next one, look at 8/13.", "Text"],

Cell[BoxData[
    \(\(sb = 
        ComputeAndPlot[GetBoundarySpecifier[bdy40, 4/7, 5/8, 240], 
          ShowLabels \[Rule] 45, ShowPleating \[Rule] 60];\)\)], "Input"],

Cell["Now 21/34.", "Text"],

Cell[BoxData[
    \(\(sb2 = 
        ComputeAndPlot[GetBoundarySpecifier[sb, 19/31, 13/21, 600], 
          ShowLabels \[Rule] 155, ShowPleating \[Rule] 200];\)\)], "Input"],

Cell["Now 55/89 and 144/233.", "Text"],

Cell[BoxData[
    \(\(sb3 = 
        ComputeAndPlot[GetBoundarySpecifier[sb2, 76/123, 34/55, 2000], 
          ShowLabels \[Rule] 750, ShowPleating \[Rule] 1000];\)\)], "Input"],

Cell["Finally 377/610.", "Text"],

Cell[BoxData[
    \(\(sb4 = 
        ComputeAndPlot[GetBoundarySpecifier[sb3, 343/555, 233/377, 6000], 
          ShowLabels \[Rule] 2000, ShowPleating \[Rule] 3000];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1440}, {0, 827}},
WindowSize->{958, 754},
WindowMargins->{{8, Automatic}, {19, Automatic}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 37, 0, 105, "Title"],
Cell[1779, 53, 150, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[1954, 60, 23, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[2002, 64, 34, 0, 47, "Subsection"],
Cell[2039, 66, 376, 7, 71, "Text"],
Cell[2418, 75, 337, 8, 70, "Input"],
Cell[2758, 85, 59, 1, 30, "Input"],
Cell[2820, 88, 67, 1, 30, "Input"],
Cell[2890, 91, 224, 3, 30, "Input"],
Cell[3117, 96, 328, 7, 71, "Text"],
Cell[3448, 105, 321, 8, 70, "Input"],
Cell[3772, 115, 68, 1, 30, "Input"],
Cell[3843, 118, 189, 3, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4069, 126, 42, 0, 31, "Subsection"],
Cell[4114, 128, 70, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[4209, 133, 114, 2, 30, "Input"],
Cell[4326, 137, 210, 3, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4573, 145, 129, 3, 30, "Input"],
Cell[4705, 150, 167, 2, 42, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4933, 159, 26, 0, 33, "Section"],
Cell[4962, 161, 197, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[5184, 169, 288, 5, 70, "Input"],
Cell[5475, 176, 1910, 42, 415, "Output"]
}, Open  ]],
Cell[7400, 221, 178, 4, 33, "Text"],
Cell[7581, 227, 157, 3, 30, "Input"],
Cell[7741, 232, 46, 0, 33, "Text"],
Cell[7790, 234, 169, 3, 30, "Input"],
Cell[7962, 239, 26, 0, 33, "Text"],
Cell[7991, 241, 173, 3, 30, "Input"],
Cell[8167, 246, 38, 0, 33, "Text"],
Cell[8208, 248, 177, 3, 30, "Input"],
Cell[8388, 253, 32, 0, 33, "Text"],
Cell[8423, 255, 181, 3, 30, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

