(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12011,        348]*)
(*NotebookOutlinePosition[     12727,        373]*)
(*  CellTagsIndexPosition[     12683,        369]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Hausdorff dimension calculations", "Title"],

Cell[CellGroupData[{

Cell["Code", "Section"],

Cell[CellGroupData[{

Cell["Data loading", "Subsection"],

Cell[BoxData[
    \(<< Statistics`LinearRegression`\)], "Input"],

Cell["\<\
Automatically attempt to load data. If the file \
maskit-mathematica-highdetail.txt is not in a subdirectory of your home \
directory, simply change the next expression to the line:
<<\"directory\\\\maskit-mathematica-highdetail.txt\"
where 'directory' is the directory where the file \
maskit-mathematica-highdetail.txt is kept, and all symbols \\ are replaced by \
\\\\.\
\>", "Text"],

Cell[BoxData[{
    \(\(filenames = 
        FileNames["\<maskit-mathematica-highdetail.txt\>", $HomeDirectory, 
          Infinity];\)\), "\[IndentingNewLine]", 
    \(\(If[
        Length[filenames] \[GreaterEqual] 
          1, \[IndentingNewLine]\(Get[
            filenames\[LeftDoubleBracket]1\[RightDoubleBracket]];\)];\)\)}], \
"Input"],

Cell[BoxData[
    \(\(LookupCusp[0] := 2\ I;\)\)], "Input"],

Cell[BoxData[
    \(\(LookupCusp[1] := 2\ I\  + \ 2;\)\)], "Input"],

Cell[BoxData[
    \(\(\(\((\(LookupCusp[#1\[LeftDoubleBracket]2\[RightDoubleBracket]] = #1\
\[LeftDoubleBracket]1\[RightDoubleBracket];\))\) &\) /@ 
        maskitbdy\[LeftDoubleBracket]2\[RightDoubleBracket];\)\)], "Input"],

Cell["\<\
Automatically attempt to load data. If the file tda2000.txt is not in a \
subdirectory of your home directory, simply change the next expression to the \
line:
<<\"directory\\\\tda2000.txt\"
where 'directory' is the directory where the file tda2000.txt is kept, and \
all symbols \\ are replaced by \\\\.\
\>", "Text"],

Cell[BoxData[{
    \(\(filenames = 
        FileNames["\<tda2000.txt\>", $HomeDirectory, 
          Infinity];\)\), "\[IndentingNewLine]", 
    \(\(If[
        Length[filenames] \[GreaterEqual] 
          1, \[IndentingNewLine]\(Get[
            filenames\[LeftDoubleBracket]1\[RightDoubleBracket]];\)];\)\)}], \
"Input"],

Cell[BoxData[
    \(\(TraceDeriv[1] := TraceDeriv[0];\)\)], "Input"],

Cell[BoxData[
    \(\(\(\((\(TraceDeriv[#1\[LeftDoubleBracket]1\[RightDoubleBracket]] = 
                Abs[#1\[LeftDoubleBracket]2\[RightDoubleBracket]];\))\) &\) /@ 
        tracederivatives;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Standard functions", "Subsection"],

Cell[BoxData[
    \(\(CpxToPair = z_Complex \[Rule] {Re[z], Im[z]};\)\)], "Input"],

Cell[BoxData[
    \(\(FareyList[qmax_] := 
        Union[Flatten[Table[p/q, {q, 1, qmax}, {p, 0, q}]]];\)\)], "Input"],

Cell[BoxData[
    \(\(FareyList[qmin_, qmax_] := 
        Select[FareyList[qmax], 
          Denominator[#1] \[GreaterEqual] qmin &];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Hausdorff dimension calculations", "Subsection"],

Cell["\<\
This function isn't entirely transparent, but it just adds |mu_i-mu_i+1|^d \
for mu_i the cusps with p/q and q<=qmax in order\
\>", "Text"],

Cell[BoxData[
    \(\(HausdorffMeasure[qmax_Integer, 
          d_:  1. ] := \(Fold[
            Function[{z, 
                m}, {z\[LeftDoubleBracket]1\[RightDoubleBracket] + 
                  Abs[z\[LeftDoubleBracket]2\[RightDoubleBracket] - 
                        m\[LeftDoubleBracket]1\[RightDoubleBracket]]^d, 
                m\[LeftDoubleBracket]1\[RightDoubleBracket]}], {0, 2  I}, 
            Select[Append[
                maskitbdy\[LeftDoubleBracket]2\[RightDoubleBracket], {2 + 
                    2  I, 1/1}], 
              Denominator[#1\[LeftDoubleBracket]2\[RightDoubleBracket]] \
\[LessEqual] qmax &]]\)[\([1]\)];\)\)], "Input"],

Cell[BoxData[
    \(\(QmaxRange = 10\ Range[50];\)\)], "Input"],

Cell[BoxData[
    \(\(HausdorffMeasureGraph[d_, opts___] := 
        ListPlot[\({#1, HausdorffMeasure[#1, d]} &\) /@ QmaxRange, 
          PlotJoined \[Rule] True, opts];\)\)], "Input"],

Cell[BoxData[
    \(\(HausdorffDimensionList = {{1. , 1.058, 1.0582}, {1.0583, 1.0584, 
            1.6}};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Covering the Maskit slice", "Subsection"],

Cell[BoxData[
    \(\(MaskitCover[coverqmin_, coverqmax_, bdyqmax_] := 
        Graphics[
          Join[\({GrayLevel[0.4 + 0.6*Denominator[#1]/coverqmax], 
                  Disk[LookupCusp[#1] /. CpxToPair, 2. /TraceDeriv[#1]], 
                  GrayLevel[0. ], 
                  Circle[LookupCusp[#1] /. CpxToPair, 
                    2. /TraceDeriv[#1]]} &\) /@ 
              Sort[FareyList[coverqmin, coverqmax], 
                Function[{r1, r2}, 
                  Denominator[r1] \[LessEqual] Denominator[r2]]], {GrayLevel[
                1. ]}, {Line[\((\((LookupCusp /@ FareyList[1, bdyqmax])\) /. 
                    CpxToPair)\)]}], 
          AspectRatio \[Rule] Automatic];\)\)], "Input"],

Cell["\<\
Select the points in l which are not a distance 2/tracederiv[r] from mu_r.\
\>", "Text"],

Cell[BoxData[
    \(\(SelMissed[l_, r_] := 
        Select[l, 
          Abs[LookupCusp[r] - #1] TraceDeriv[r] \[GreaterEqual] 
              2 &];\)\)], "Input"],

Cell["\<\
Lists the points missed by the cover consisting of all discs of radius \
2/tracederiv(p/q) for q>=qmin\
\>", "Text"],

Cell[BoxData[
    \(\(CoverMissPoints[qmin_] := 
        Module[{mb, sl}, \[IndentingNewLine]mb = 
            LookupCusp /@ FareyList[500]; \[IndentingNewLine]sl = 
            Sort[FareyList[qmin, 100], 
              Denominator[#1] \[LessEqual] 
                  Denominator[#2] &]; \[IndentingNewLine]Fold[SelMissed, mb, 
            sl]];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Results", "Section"],

Cell[CellGroupData[{

Cell["Hausdorff dimension", "Subsection"],

Cell["\<\
Six graphs showing how the estimate of the d-dimensional Hausdorff measure \
changes as you increase q, for various values of d. Together, they suggest \
that the Hausdorff dimension of the Maskit slice is somewhere between 1.0582 \
and 1.0584.\
\>", "Text"],

Cell[BoxData[
    \(\(Show[
        GraphicsArray[
          Map[HausdorffMeasureGraph[#1, DisplayFunction \[Rule] Identity, 
                PlotLabel \[Rule] "\<d=\>" <> ToString[#1]] &, 
            HausdorffDimensionList, {2}]], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear measure", "Subsection"],

Cell["\<\
The following statistical analysis suggests that the linear measure of the \
Maskit slice is infinite, it seems that if you approximate it up to order \
qmax, then the approximate length grows like const. qmax ^ 0.1 with r^2 \
values of about 0.999 (i.e. very good).\
\>", "Text"],

Cell[BoxData[
    \(\(LinearMeasureList = \({#1, 
              HausdorffMeasure[#1, 1. ]} &\) /@ \((5\ Range[
                100])\);\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[LinearMeasureList, PlotJoined \[Rule] True];\)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[\({Log[#1\[LeftDoubleBracket]1\[RightDoubleBracket]], 
              Log[#1\[LeftDoubleBracket]2\[RightDoubleBracket]]} &\) /@ 
          LinearMeasureList];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Regress[\({Log[#1\[LeftDoubleBracket]1\[RightDoubleBracket]], 
            Log[#1\[LeftDoubleBracket]2\[RightDoubleBracket]]} &\) /@ 
        LinearMeasureList, {1, x}, x]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"1", "0.6351384431558772`", "0.0009667302107071279`", 
                  "656.996580970917`", "0.`"},
                {"x", "0.1047616412338553`", "0.00018146148588230298`", 
                  "577.321632325905`", "0.`"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            (
            TableForm[ #, TableHeadings -> {{1, x}, {"Estimate", "SE", 
              "TStat", "PValue"}}]&)]}], 
        ",", \(RSquared \[Rule] 0.9997060572604732`\), 
        ",", \(AdjustedRSquared \[Rule] 0.9997030578447638`\), 
        ",", \(EstimatedVariance \[Rule] 2.807694500188881`*^-6\), ",", 
        RowBox[{"ANOVATable", "\[Rule]", 
          InterpretationBox[GridBox[{
                {"\<\"\"\>", "\<\"DF\"\>", "\<\"SumOfSq\"\>", \
"\<\"MeanSq\"\>", "\<\"FRatio\"\>", "\<\"PValue\"\>"},
                {"\<\"Model\"\>", "1", "0.9358053269925978`", 
                  "0.9358053269925978`", "333300.2671514453`", "0.`"},
                {"\<\"Error\"\>", "98", "0.00027515406101851034`", 
                  "2.807694500188881`*^-6", "\<\"\"\>", "\<\"\"\>"},
                {"\<\"Total\"\>", "99", 
                  "0.9360804810536163`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            
            TableForm[ {{1, .93580532699259777, .93580532699259777, 
              333300.26715144532, 0.0}, {
              98, .00027515406101851034, .28076945001888809*^-5}, {
              99, .9360804810536163}}, TableHeadings -> {{"Model", "Error", 
              "Total"}, {"DF", "SumOfSq", "MeanSq", "FRatio", 
              "PValue"}}]]}]}], "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Covering the Maskit slice", "Subsection"],

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{{MaskitCover[2, 30, 80], 
              MaskitCover[3, 30, 80]}, {MaskitCover[4, 30, 80], 
              MaskitCover[8, 30, 80]}}]];\)\)], "Input"],

Cell["\<\
A plot of the points missed by the cover with q>5. In the plot there are lots \
of points, but they are just the ones near to certain key points (so that \
each 'point' is actually a cluster of points). The key points are the cusps \
with q<=5. We are limited to q<=500 in this plot, but if we let q<\[Infinity] \
it seems likely that the only points left would be the cusps q<=5.\
\>", "Text"],

Cell[BoxData[
    \(\(ListPlot[CoverMissPoints[5] /. CpxToPair, PlotRange \[Rule] All, 
        Axes \[Rule] False, AspectRatio -> Automatic];\)\)], "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1440}, {0, 827}},
WindowSize->{952, 782},
WindowMargins->{{20, Automatic}, {3, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 49, 0, 105, "Title"],

Cell[CellGroupData[{
Cell[1813, 55, 23, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[1861, 59, 34, 0, 47, "Subsection"],
Cell[1898, 61, 64, 1, 30, "Input"],
Cell[1965, 64, 396, 8, 71, "Text"],
Cell[2364, 74, 343, 8, 70, "Input"],
Cell[2710, 84, 59, 1, 30, "Input"],
Cell[2772, 87, 67, 1, 30, "Input"],
Cell[2842, 90, 224, 3, 30, "Input"],
Cell[3069, 95, 328, 7, 71, "Text"],
Cell[3400, 104, 321, 8, 70, "Input"],
Cell[3724, 114, 68, 1, 30, "Input"],
Cell[3795, 117, 209, 3, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4041, 125, 40, 0, 31, "Subsection"],
Cell[4084, 127, 82, 1, 30, "Input"],
Cell[4169, 130, 118, 2, 30, "Input"],
Cell[4290, 134, 148, 3, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4475, 142, 54, 0, 31, "Subsection"],
Cell[4532, 144, 149, 3, 33, "Text"],
Cell[4684, 149, 654, 12, 70, "Input"],
Cell[5341, 163, 63, 1, 30, "Input"],
Cell[5407, 166, 185, 3, 30, "Input"],
Cell[5595, 171, 121, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5753, 178, 47, 0, 31, "Subsection"],
Cell[5803, 180, 709, 13, 150, "Input"],
Cell[6515, 195, 98, 2, 33, "Text"],
Cell[6616, 199, 162, 4, 30, "Input"],
Cell[6781, 205, 126, 3, 33, "Text"],
Cell[6910, 210, 360, 7, 90, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7319, 223, 26, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[7370, 227, 41, 0, 47, "Subsection"],
Cell[7414, 229, 268, 5, 52, "Text"],
Cell[7685, 236, 299, 6, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8021, 247, 36, 0, 31, "Subsection"],
Cell[8060, 249, 290, 5, 52, "Text"],
Cell[8353, 256, 150, 3, 30, "Input"],
Cell[8506, 261, 90, 1, 30, "Input"],
Cell[8599, 264, 203, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[8827, 271, 204, 3, 30, "Input"],
Cell[9034, 276, 2073, 43, 150, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[11156, 325, 47, 0, 31, "Subsection"],
Cell[11206, 327, 198, 4, 30, "Input"],
Cell[11407, 333, 404, 6, 52, "Text"],
Cell[11814, 341, 157, 2, 30, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

