(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4172,        123]*)
(*NotebookOutlinePosition[      4826,        146]*)
(*  CellTagsIndexPosition[      4782,        142]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Invertibility Regions", "Title"],

Cell[TextData[StyleBox["Before running this notebook, evaluate the cells in \
the \"Code\" section of the algorithms-chapter.nb notebook.",
  FontWeight->"Bold"]], "Text"],

Cell["\<\
This function evaluates the trace derivative at numsamp points around the p/q \
cusp, and returns the minimum as a proportion of the trace derivative at the \
cusp. This number always seems to be well away from 0, and so we conclude \
that in this region the trace derivative is always nonzero. This strongly \
suggests the function is invertible on this region.\
\>", "Text"],

Cell[BoxData[
    \(\(LocalCoordTest[rat_, numsamp_, showgraphs_:  False, eps_:  1] := 
        Module[\[IndentingNewLine]{cusp, td, samppoints, derivs, 
            imgpoints}, \[IndentingNewLine]cusp = 
            FindCuspPleating[rat]; \[IndentingNewLine]td = 
            DTrF[rat, cusp]; \[IndentingNewLine]samppoints = 
            Table[cusp + 
                eps*Random[Complex, {\(-1\) - I, 1 + I}]/
                    Abs[td], {numsamp}]; \[IndentingNewLine]If[showgraphs, 
            ListPlot[samppoints /. CpxToPair, 
              AspectRatio \[Rule] 
                Automatic]; \[IndentingNewLine]imgpoints = \(TrF[
                    rat, #1] &\) /@ samppoints; \[IndentingNewLine]ListPlot[
              imgpoints /. CpxToPair, 
              AspectRatio \[Rule] 
                Automatic];]; \[IndentingNewLine]derivs = \(Abs[
                  DTrF[rat, #1]] &\) /@ samppoints; \[IndentingNewLine]Min[
              derivs]/Abs[td]\[IndentingNewLine]];\)\)], "Input"],

Cell["\<\
The graphs here show the randomly selected points near the cusp, and their \
image under the trace map. It seems likely that this image is simply \
connected.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LocalCoordTest[789/1234, 1000, True, 0.5]\)], "Input"],

Cell[BoxData[
    \(0.8668973555244331`\)], "Output"]
}, Open  ]],

Cell["\<\
These are the smallest trace derivative proportions for q<=40 and q<=80 \
respectively.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Min[\(LocalCoordTest[#1, 1000] &\) /@ FareyList[40]]\)], "Input"],

Cell[BoxData[
    \(0.6876269548638443`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Min[\(LocalCoordTest[#1, 100] &\) /@ FareyList[80]]\)], "Input"],

Cell[BoxData[
    \(0.6851654448494302`\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1440}, {0, 827}},
WindowSize->{638, 730},
WindowMargins->{{6, Automatic}, {15, Automatic}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 38, 0, 105, "Title"],
Cell[1780, 53, 171, 2, 33, "Text"],
Cell[1954, 57, 386, 6, 71, "Text"],
Cell[2343, 65, 992, 17, 270, "Input"],
Cell[3338, 84, 182, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[3545, 92, 74, 1, 30, "Input"],
Cell[3622, 95, 53, 1, 29, "Output"]
}, Open  ]],
Cell[3690, 99, 111, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[3826, 106, 85, 1, 30, "Input"],
Cell[3914, 109, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4004, 115, 84, 1, 30, "Input"],
Cell[4091, 118, 53, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

